texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

branch master updated: @var roman slanted everywhere @code no explicit u


From: Patrice Dumas
Subject: branch master updated: @var roman slanted everywhere @code no explicit upright in def
Date: Wed, 10 Aug 2022 17:35:11 -0400

This is an automated email from the git hooks/post-receive script.

pertusus pushed a commit to branch master
in repository texinfo.

The following commit(s) were added to refs/heads/master by this push:
     new 39195cb1d9 @var roman slanted everywhere @code no explicit upright in 
def
39195cb1d9 is described below

commit 39195cb1d9a5ba6ea84540a518058e5e27a73844
Author: Patrice Dumas <pertusus@free.fr>
AuthorDate: Wed Aug 10 23:31:59 2022 +0200

    @var roman slanted everywhere @code no explicit upright in def
    
    * tp/Texinfo/Convert/LaTeX.pm (_convert): use a macro to define
    @var similarly to @cite, with \normalfont.  Use it in text
    context.  Set the @cite formatting with \normalfont for text
    context too.  Remove codetext context, remove 'var_slant' context.
---
 ChangeLog                                          |  9 ++
 tp/Texinfo/Convert/LaTeX.pm                        | 68 +++++-----------
 .../res_latex/definition_commands.tex              | 95 +++++++++++-----------
 .../def_syn_indices/res_latex/def_syn_indices.tex  |  5 +-
 tp/t/results/latex_tests/combined_fonts.pl         | 16 ++--
 .../combined_fonts/res_latex/combined_fonts.tex    | 23 +++---
 .../res_latex/inter_item_commands_in_table.tex     | 11 ++-
 .../inter_item_commands_in_table_in_example.tex    | 11 ++-
 .../indices_in_begin_tables_lists.tex              | 11 ++-
 .../indices_in_begin_tables_lists.tex              | 11 ++-
 .../res_parser/formatting_latex/formatting.tex     | 89 ++++++++++----------
 11 files changed, 179 insertions(+), 170 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 85c4e1a350..657d825eae 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2022-08-10  Patrice Dumas  <pertusus@free.fr>
+
+       @var roman slanted everywhere @code no explicit upright in def
+
+       * tp/Texinfo/Convert/LaTeX.pm (_convert): use a macro to define
+       @var similarly to @cite, with \normalfont.  Use it in text
+       context.  Set the @cite formatting with \normalfont for text
+       context too.  Remove codetext context, remove 'var_slant' context.
+
 2022-08-10  Gavin Smith  <gavinsmith0123@gmail.com>
 
        * doc/texinfo.texi (Typed Functions): Add output of Ada example and
diff --git 
a/tp/t/results/converters_tests/definition_commands/res_latex/definition_commands.tex
 
b/tp/t/results/converters_tests/definition_commands/res_latex/definition_commands.tex
index 7bf3693147..8d0dc49bdd 100644
--- 
a/tp/t/results/converters_tests/definition_commands/res_latex/definition_commands.tex
+++ 
b/tp/t/results/converters_tests/definition_commands/res_latex/definition_commands.tex
@@ -21,6 +21,9 @@
 \makeindex[name=fn]%
 \makeindex[name=vr]%
 
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
+
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
 \renewcommand\mainmatter{\clearpage\@mainmattertrue\pagenumbering{arabic}}
@@ -81,17 +84,17 @@
 \index[fn]{fname@\texttt{fname}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-deffn no var for \textsl{a---rg1} and \textsl{a--rg2}
+deffn no var for \GNUTexinfocommandstyletextvar{a---rg1} and 
\GNUTexinfocommandstyletextvar{a--rg2}
 \end{quote}
 
-\noindent\texttt{fname \EmbracOn{}\textnormal{\textsl{{\rmfamily \slshape 
a---rg1} {\rmfamily \slshape a--rg2}}}\EmbracOff{}}\hfill[Func]
+\noindent\texttt{fname 
\EmbracOn{}\textnormal{\textsl{\GNUTexinfocommandstyletextvar{a---rg1} 
\GNUTexinfocommandstyletextvar{a--rg2}}}\EmbracOff{}}\hfill[Func]
 
 
 
 \index[fn]{fname@\texttt{fname}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-deffn explict var for \textsl{a---rg1} and \textsl{a--rg2}
+deffn explict var for \GNUTexinfocommandstyletextvar{a---rg1} and 
\GNUTexinfocommandstyletextvar{a--rg2}
 \end{quote}
 
 \noindent\texttt{fname 
\EmbracOn{}\textnormal{\textsl{\EmbracOff{}\textnormal{\textsl{a---rg1}}\EmbracOn{}
 \EmbracOff{}\textnormal{\textsl{a--rg2}}\EmbracOn{}}}\EmbracOff{}}\hfill[Func]
@@ -101,7 +104,7 @@ deffn explict var for \textsl{a---rg1} and \textsl{a--rg2}
 \index[fn]{fname@\texttt{fname}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-deffn r slanted for \textsl{a---rg1} and \textsl{a--rg2}
+deffn r slanted for \GNUTexinfocommandstyletextvar{a---rg1} and 
\GNUTexinfocommandstyletextvar{a--rg2}
 \end{quote}
 
 \noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var [from to [inc]]) 
default}}\EmbracOff{}}\hfill[Special Form]
@@ -114,7 +117,7 @@ deffn r slanted for \textsl{a---rg1} and \textsl{a--rg2}
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var {\rmfamily 
\slshape [}from to {\rmfamily \slshape [}inc{\rmfamily \slshape ]]}) 
var}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var 
\GNUTexinfocommandstyletextvar{[}from to 
\GNUTexinfocommandstyletextvar{[}inc\GNUTexinfocommandstyletextvar{]]}) 
var}}\EmbracOff{}}\hfill[Special Form]
 
 
 
@@ -124,7 +127,7 @@ deffn r slanted for \textsl{a---rg1} and \textsl{a--rg2}
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var 
\EmbracMakeKnown{texttt}{\upshape \ttfamily [}from to {\upshape \ttfamily 
[}inc{\upshape \ttfamily ]]}) code}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var 
\EmbracMakeKnown{texttt}\texttt{[}from to \texttt{[}inc\texttt{]]}) 
code}}\EmbracOff{}}\hfill[Special Form]
 
 
 \ExplSyntaxOn%
@@ -146,7 +149,7 @@ deffn r slanted for \textsl{a---rg1} and \textsl{a--rg2}
 
\cs_undefine:N{\embrac_texttt:nn}\cs_undefine:N{\embrac_orig_texttt:n}\cs_undefine:N{\__embrac_texttt:n}%
 \ExplSyntaxOff%
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var 
\EmbracOff{}\textnormal{{\rmfamily \slshape [}}\EmbracOn{}from to 
\EmbracOff{}\textnormal{{\rmfamily \slshape 
[}}\EmbracOn{}inc\EmbracOff{}\textnormal{{\rmfamily \slshape ]]}}\EmbracOn{}) 
r:var}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var 
\EmbracOff{}\textnormal{\GNUTexinfocommandstyletextvar{[}}\EmbracOn{}from to 
\EmbracOff{}\textnormal{\GNUTexinfocommandstyletextvar{[}}\EmbracOn{}inc\EmbracOff{}\textnormal{\GNUTexinfocommandstyletextvar{]]}}\EmbracOn{})
 r:var}}\EmbracOff{}}\hfill[Special Form]
 
 
 
@@ -156,7 +159,7 @@ deffn r slanted for \textsl{a---rg1} and \textsl{a--rg2}
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var 
\EmbracOff{}\textnormal{{\upshape \ttfamily [}}\EmbracOn{}from to 
\EmbracOff{}\textnormal{{\upshape \ttfamily 
[}}\EmbracOn{}inc\EmbracOff{}\textnormal{{\upshape \ttfamily ]]}}\EmbracOn{}) 
r:code}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{(var 
\EmbracOff{}\textnormal{\texttt{[}}\EmbracOn{}from to 
\EmbracOff{}\textnormal{\texttt{[}}\EmbracOn{}inc\EmbracOff{}\textnormal{\texttt{]]}}\EmbracOn{})
 r:code}}\EmbracOff{}}\hfill[Special Form]
 
 
 
@@ -176,7 +179,7 @@ separators
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{{\rmfamily \slshape 
va---riable} var}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar 
\EmbracOn{}\textnormal{\textsl{\GNUTexinfocommandstyletextvar{va---riable} 
var}}\EmbracOff{}}\hfill[Special Form]
 
 
 
@@ -191,7 +194,7 @@ separators
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar 
\EmbracOn{}\textnormal{\textsl{\EmbracMakeKnown{texttt}{\upshape \ttfamily 
va{-}{-}{-}riable} code}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar 
\EmbracOn{}\textnormal{\textsl{\EmbracMakeKnown{texttt}\texttt{va{-}{-}{-}riable}
 code}}\EmbracOff{}}\hfill[Special Form]
 
 
 \ExplSyntaxOn%
@@ -213,7 +216,7 @@ separators
 
\cs_undefine:N{\embrac_texttt:nn}\cs_undefine:N{\embrac_orig_texttt:n}\cs_undefine:N{\__embrac_texttt:n}%
 \ExplSyntaxOff%
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar 
\EmbracOn{}\textnormal{\textsl{\EmbracOff{}\textnormal{{\rmfamily \slshape 
va---riable}}\EmbracOn{} r:var}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar 
\EmbracOn{}\textnormal{\textsl{\EmbracOff{}\textnormal{\GNUTexinfocommandstyletextvar{va---riable}}\EmbracOn{}
 r:var}}\EmbracOff{}}\hfill[Special Form]
 
 
 
@@ -223,7 +226,7 @@ separators
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar 
\EmbracOn{}\textnormal{\textsl{\EmbracOff{}\textnormal{{\upshape \ttfamily 
va{-}{-}{-}riable}}\EmbracOn{} r:code}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar 
\EmbracOn{}\textnormal{\textsl{\EmbracOff{}\textnormal{\texttt{va{-}{-}{-}riable}}\EmbracOn{}
 r:code}}\EmbracOff{}}\hfill[Special Form]
 
 
 
@@ -268,18 +271,18 @@ name
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
 The \texttt{ft} request and the \texttt{\textbackslash{}f} escape change the 
current font
-to \textsl{font} (one-character name\hbox{}\textsl{f}, two-character name
-\textsl{fn}).
+to \GNUTexinfocommandstyletextvar{font} (one-character 
name\hbox{}\GNUTexinfocommandstyletextvar{f}, two-character name
+\GNUTexinfocommandstyletextvar{fn}).
 \end{quote}
 
-\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{[ 
\EmbracOff{}\textnormal{[}\EmbracOn{} \textsl{[} 
\EmbracMakeKnown{texttt}{\upshape \ttfamily [} \texttt{[} 
\EmbracOff{}\textnormal{\textsl{[}}\EmbracOn{} 
\EmbracOff{}\textnormal{{\upshape \ttfamily [}}\EmbracOn{} 
\EmbracOff{}\textnormal{{\upshape \ttfamily \textsl{[}}}\EmbracOn{} 
\EmbracOff{}\textnormal{\texttt{[}}\EmbracOn{} , 
\EmbracOff{}\textnormal{,}\EmbracOn{} \textsl{,} {\upshape \ttfamily ,} 
\texttt{,} \EmbracOff{}\textnorma [...]
+\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{[ 
\EmbracOff{}\textnormal{[}\EmbracOn{} \textsl{[} 
\EmbracMakeKnown{texttt}\texttt{[} \texttt{[} 
\EmbracOff{}\textnormal{\textsl{[}}\EmbracOn{} 
\EmbracOff{}\textnormal{\texttt{[}}\EmbracOn{} 
\EmbracOff{}\textnormal{\texttt{\textsl{[}}}\EmbracOn{} 
\EmbracOff{}\textnormal{\texttt{[}}\EmbracOn{} , 
\EmbracOff{}\textnormal{,}\EmbracOn{} \textsl{,} \texttt{,} \texttt{,} 
\EmbracOff{}\textnormal{\textsl{,}}\EmbracOn{} \EmbracOff{}\textnormal [...]
 
 
 \ExplSyntaxOn%
 
\cs_undefine:N{\embrac_texttt:nn}\cs_undefine:N{\embrac_orig_texttt:n}\cs_undefine:N{\__embrac_texttt:n}%
 \ExplSyntaxOff%
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{[] 
\EmbracOff{}\textnormal{[]}\EmbracOn{} \textsl{[]} 
\EmbracMakeKnown{texttt}{\upshape \ttfamily []} \texttt{[]} 
\EmbracOff{}\textnormal{\textsl{[]}}\EmbracOn{} 
\EmbracOff{}\textnormal{{\upshape \ttfamily []}}\EmbracOn{} 
\EmbracOff{}\textnormal{{\upshape \ttfamily 
\textsl{[]}}}\EmbracOn{}}}\EmbracOff{}}\hfill[Special Form]
+\noindent\texttt{foobar \EmbracOn{}\textnormal{\textsl{[] 
\EmbracOff{}\textnormal{[]}\EmbracOn{} \textsl{[]} 
\EmbracMakeKnown{texttt}\texttt{[]} \texttt{[]} 
\EmbracOff{}\textnormal{\textsl{[]}}\EmbracOn{} 
\EmbracOff{}\textnormal{\texttt{[]}}\EmbracOn{} 
\EmbracOff{}\textnormal{\texttt{\textsl{[]}}}\EmbracOn{}}}\EmbracOff{}}\hfill[Special
 Form]
 
 
 \ExplSyntaxOn%
@@ -291,14 +294,14 @@ to \textsl{font} (one-character name\hbox{}\textsl{f}, 
two-character name
 test formatting of separators
 \end{quote}
 
-\noindent\texttt{int foobar (int {\rmfamily \slshape f---oo}, float {\rmfamily 
\slshape b--ar})}\hfill[Library Function]
+\noindent\texttt{int foobar (int \GNUTexinfocommandstyletextvar{f---oo}, float 
\GNUTexinfocommandstyletextvar{b--ar})}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-\dots{}\@ with var for \textsl{f---oo} and \textsl{b--ar}
+\dots{}\@ with var for \GNUTexinfocommandstyletextvar{f---oo} and 
\GNUTexinfocommandstyletextvar{b--ar}
 \end{quote}
 
 \noindent\texttt{int foobar (int \textnormal{\textsl{f---oo}}, float 
\textnormal{\textsl{b--ar}})}\hfill[Library Function]
@@ -308,7 +311,7 @@ test formatting of separators
 \index[fn]{foobar@\texttt{foobar}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-\dots{}\@ with r slanted for \textsl{f---oo} and \textsl{b--ar}
+\dots{}\@ with r slanted for \GNUTexinfocommandstyletextvar{f---oo} and 
\GNUTexinfocommandstyletextvar{b--ar}
 \end{quote}
 
 \noindent{}produces:
@@ -333,14 +336,14 @@ test formatting of separators
 \end{quote}
 
 \begin{quote}
-\noindent\texttt{int foobar (int {\rmfamily \slshape foo}, float {\rmfamily 
\slshape bar})}\hfill[Library Function]
+\noindent\texttt{int foobar (int \GNUTexinfocommandstyletextvar{foo}, float 
\GNUTexinfocommandstyletextvar{bar})}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-\dots{}\@ for \textsl{foo} and \textsl{bar}
+\dots{}\@ for \GNUTexinfocommandstyletextvar{foo} and 
\GNUTexinfocommandstyletextvar{bar}
 \end{quote}
 \end{quote}
 
@@ -351,7 +354,7 @@ test formatting of separators
 \index[fn]{apply@\texttt{apply}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-\texttt{apply} calls no var \textsl{function} with \textsl{arguments}
+\texttt{apply} calls no var \GNUTexinfocommandstyletextvar{function} with 
\GNUTexinfocommandstyletextvar{arguments}
 \end{quote}
 
 \noindent\texttt{apply \EmbracOn{}\textnormal{\textsl{function 
\EmbracOff{}\textnormal{\textbf{\&rest}}\EmbracOn{} 
argument}}\EmbracOff{}}\hfill[Function]
@@ -361,10 +364,10 @@ test formatting of separators
 \index[fn]{apply@\texttt{apply}}%
 \begin{quote}
 \unskip{\parskip=0pt\noindent}%
-explicit keyword marking, no var \textsl{function} with \textsl{arguments}
+explicit keyword marking, no var \GNUTexinfocommandstyletextvar{function} with 
\GNUTexinfocommandstyletextvar{arguments}
 \end{quote}
 
-\noindent\texttt{name \EmbracOn{}\textnormal{\textsl{argument 
\EmbracMakeKnown{texttt}{\upshape \ttfamily int} {\upshape \ttfamily a{-}{-}b} 
{\rmfamily \slshape v--ar1}, word {\upshape \ttfamily {-}{-}} ({\upshape 
\ttfamily type o{-}{-}ther}, {\rmfamily \slshape v---ar2}  [{\upshape \ttfamily 
float} [{\rmfamily \slshape var4}]])}}\EmbracOff{}}\hfill[Category]
+\noindent\texttt{name \EmbracOn{}\textnormal{\textsl{argument 
\EmbracMakeKnown{texttt}\texttt{int} \texttt{a{-}{-}b} 
\GNUTexinfocommandstyletextvar{v--ar1}, word \texttt{{-}{-}} (\texttt{type 
o{-}{-}ther}, \GNUTexinfocommandstyletextvar{v---ar2}  [\texttt{float} 
[\GNUTexinfocommandstyletextvar{var4}]])}}\EmbracOff{}}\hfill[Category]
 
 
 \ExplSyntaxOn%
@@ -376,57 +379,57 @@ explicit keyword marking, no var \textsl{function} with 
\textsl{arguments}
 In deffn with code and var used
 \end{quote}
 
-\noindent\texttt{int foobar (int {\rmfamily \slshape f---oo}[, float 
{\rmfamily \slshape b--ar}]) default}\hfill[Library Function]
+\noindent\texttt{int foobar (int \GNUTexinfocommandstyletextvar{f---oo}[, 
float \GNUTexinfocommandstyletextvar{b--ar}]) default}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape f---oo}\textnormal{[}, 
float {\rmfamily \slshape b--ar}\textnormal{]}) r}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\textnormal{[}, float 
\GNUTexinfocommandstyletextvar{b--ar}\textnormal{]}) r}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape f---oo}{\rmfamily 
\slshape [}, float {\rmfamily \slshape b--ar}{\rmfamily \slshape ]}) 
var}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\GNUTexinfocommandstyletextvar{[}, float 
\GNUTexinfocommandstyletextvar{b--ar}\GNUTexinfocommandstyletextvar{]}) 
var}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape f---oo}\textsl{[}, float 
{\rmfamily \slshape b--ar}\textsl{]}) slanted}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\textsl{[}, float 
\GNUTexinfocommandstyletextvar{b--ar}\textsl{]}) slanted}\hfill[Library 
Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape f---oo}{\upshape 
\ttfamily [}, float {\rmfamily \slshape b--ar}{\upshape \ttfamily ]}) 
code}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\texttt{[}, float 
\GNUTexinfocommandstyletextvar{b--ar}\texttt{]}) code}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape f---oo}\texttt{[}, float 
{\rmfamily \slshape b--ar}\texttt{]}) t}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\texttt{[}, float 
\GNUTexinfocommandstyletextvar{b--ar}\texttt{]}) t}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape 
f---oo}\texttt{\textbf{[}}, float {\rmfamily \slshape 
b--ar}\texttt{\textbf{]}}) t:b}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\texttt{\textbf{[}}, float 
\GNUTexinfocommandstyletextvar{b--ar}\texttt{\textbf{]}}) t:b}\hfill[Library 
Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape 
f---oo}\textnormal{{\rmfamily \slshape [}}, float {\rmfamily \slshape 
b--ar}\textnormal{{\rmfamily \slshape ]}}) r:var}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\textnormal{\GNUTexinfocommandstyletextvar{[}},
 float 
\GNUTexinfocommandstyletextvar{b--ar}\textnormal{\GNUTexinfocommandstyletextvar{]}})
 r:var}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape 
f---oo}\textnormal{\textsl{[}}, float {\rmfamily \slshape 
b--ar}\textnormal{\textsl{]}}) r:slanted}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\textnormal{\textsl{[}}, float 
\GNUTexinfocommandstyletextvar{b--ar}\textnormal{\textsl{]}}) 
r:slanted}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape 
f---oo}\textnormal{{\upshape \ttfamily [}}, float {\rmfamily \slshape 
b--ar}\textnormal{{\upshape \ttfamily ]}}) r:code}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\textnormal{\texttt{[}}, float 
\GNUTexinfocommandstyletextvar{b--ar}\textnormal{\texttt{]}}) 
r:code}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (int {\rmfamily \slshape 
f---oo}\textnormal{\texttt{[}}, float {\rmfamily \slshape 
b--ar}\textnormal{\texttt{]}}) r:t}\hfill[Library Function]
+\noindent\texttt{int foobar (int 
\GNUTexinfocommandstyletextvar{f---oo}\textnormal{\texttt{[}}, float 
\GNUTexinfocommandstyletextvar{b--ar}\textnormal{\texttt{]}}) 
r:t}\hfill[Library Function]
 
 
 
@@ -436,57 +439,57 @@ In deffn with code and var used
 separators
 \end{quote}
 
-\noindent\texttt{int foobar (i{-}{-}nt {\rmfamily \slshape f---oo}[, float 
{\rmfamily \slshape b--ar}]) default}\hfill[Library Function]
+\noindent\texttt{int foobar (i{-}{-}nt 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) default}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\textnormal{i--nt} {\rmfamily \slshape f---oo}[, 
float {\rmfamily \slshape b--ar}]) r}\hfill[Library Function]
+\noindent\texttt{int foobar (\textnormal{i--nt} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) r}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar ({\rmfamily \slshape i--nt} {\rmfamily \slshape 
f---oo}[, float {\rmfamily \slshape b--ar}]) var}\hfill[Library Function]
+\noindent\texttt{int foobar (\GNUTexinfocommandstyletextvar{i--nt} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) var}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\textsl{i{-}{-}nt} {\rmfamily \slshape f---oo}[, 
float {\rmfamily \slshape b--ar}]) slanted}\hfill[Library Function]
+\noindent\texttt{int foobar (\textsl{i{-}{-}nt} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) slanted}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar ({\upshape \ttfamily i{-}{-}nt} {\rmfamily 
\slshape f---oo}[, float {\rmfamily \slshape b--ar}]) code}\hfill[Library 
Function]
+\noindent\texttt{int foobar (\texttt{i{-}{-}nt} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) code}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\texttt{i{-}{-}nt} {\rmfamily \slshape f---oo}[, 
float {\rmfamily \slshape b--ar}]) t}\hfill[Library Function]
+\noindent\texttt{int foobar (\texttt{i{-}{-}nt} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) t}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\texttt{\textbf{i{-}{-}nt}} {\rmfamily \slshape 
f---oo}[, float {\rmfamily \slshape b--ar}]) t:b}\hfill[Library Function]
+\noindent\texttt{int foobar (\texttt{\textbf{i{-}{-}nt}} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) t:b}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\textnormal{{\rmfamily \slshape i--nt}} 
{\rmfamily \slshape f---oo}[, float {\rmfamily \slshape b--ar}]) 
r:var}\hfill[Library Function]
+\noindent\texttt{int foobar 
(\textnormal{\GNUTexinfocommandstyletextvar{i--nt}} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) r:var}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\textnormal{\textsl{i--nt}} {\rmfamily \slshape 
f---oo}[, float {\rmfamily \slshape b--ar}]) r:slanted}\hfill[Library Function]
+\noindent\texttt{int foobar (\textnormal{\textsl{i--nt}} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) r:slanted}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\textnormal{{\upshape \ttfamily i{-}{-}nt}} 
{\rmfamily \slshape f---oo}[, float {\rmfamily \slshape b--ar}]) 
r:code}\hfill[Library Function]
+\noindent\texttt{int foobar (\textnormal{\texttt{i{-}{-}nt}} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) r:code}\hfill[Library Function]
 
 
 
 \index[fn]{foobar@\texttt{foobar}}%
-\noindent\texttt{int foobar (\textnormal{\texttt{i{-}{-}nt}} {\rmfamily 
\slshape f---oo}[, float {\rmfamily \slshape b--ar}]) r:t}\hfill[Library 
Function]
+\noindent\texttt{int foobar (\textnormal{\texttt{i{-}{-}nt}} 
\GNUTexinfocommandstyletextvar{f---oo}[, float 
\GNUTexinfocommandstyletextvar{b--ar}]) r:t}\hfill[Library Function]
 
 
 
diff --git a/tp/t/results/indices/def_syn_indices/res_latex/def_syn_indices.tex 
b/tp/t/results/indices/def_syn_indices/res_latex/def_syn_indices.tex
index c05c2665ed..c1f2f37eed 100644
--- a/tp/t/results/indices/def_syn_indices/res_latex/def_syn_indices.tex
+++ b/tp/t/results/indices/def_syn_indices/res_latex/def_syn_indices.tex
@@ -20,6 +20,9 @@
 \makeindex[name=fn]%
 \makeindex[name=pg]%
 
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
+
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
 \renewcommand\mainmatter{\clearpage\@mainmattertrue\pagenumbering{arabic}}
@@ -76,7 +79,7 @@ after
 \index[fn]{index truc}%
 
 
-\index[codeidx]{a index entry te\~{} i\^{}@\texttt{a \textsl{index entry} 
t\~{e} \^{\i{}}}}%
+\index[codeidx]{a index entry te\~{} i\^{}@\texttt{a 
\GNUTexinfocommandstyletextvar{index entry} t\~{e} \^{\i{}}}}%
 
 \index[fn]{cindex entry@\texttt{cindex entry}}%
 
diff --git a/tp/t/results/latex_tests/combined_fonts.pl 
b/tp/t/results/latex_tests/combined_fonts.pl
index 6adeb2292b..9d821e9013 100644
--- a/tp/t/results/latex_tests/combined_fonts.pl
+++ b/tp/t/results/latex_tests/combined_fonts.pl
@@ -1519,19 +1519,19 @@ $result_converted{'latex'}->{'combined_fonts'} = '
 \\chapter{{chapter}}
 \\label{anchor:chapter}%
 
-\\texttt{code}, \\textsl{dfn}, \\textsl{var}, \\textbf{strong}, 
{\\ttfamily\\textsl{kbd}}, `\\texttt{samp}\'.
+\\texttt{code}, \\textsl{dfn}, \\GNUTexinfocommandstyletextvar{var}, 
\\textbf{strong}, {\\ttfamily\\textsl{kbd}}, `\\texttt{samp}\'.
 
 \\texttt{\\textsl{dfn in code}}
-\\textsl{\\texttt{code in var}}
-\\texttt{\\textsl{var in code}}
+\\GNUTexinfocommandstyletextvar{\\texttt{code in var}}
+\\texttt{\\GNUTexinfocommandstyletextvar{var in code}}
 \\textbf{{\\ttfamily\\textsl{kbd in strong}}}
 `\\texttt{\\textbf{strong in samp}}\'
 \\textbf{`\\texttt{samp in strong}\'}
 
-\\textsl{cite}
+\\GNUTexinfocommandstyletextcite{cite}
 
-\\texttt{\\GNUTexinfocommandstylecodetextcite{cite in code}}
-\\textsl{\\texttt{code in cite}}
+\\texttt{\\GNUTexinfocommandstyletextcite{cite in code}}
+\\GNUTexinfocommandstyletextcite{\\texttt{code in cite}}
 
 \\texttt{code} \\textsl{slanted} \\textbf{b}
 \\texttt{\\textsl{slanted in code}}
@@ -1541,8 +1541,8 @@ $result_converted{'latex'}->{'combined_fonts'} = '
 
 \\begin{GNUTexinfopreformatted}
 \\leftskip=2em\\relax\\ttfamily%
-\\textsl{var in example}
-\\GNUTexinfocommandstylecodetextcite{cite in example}
+\\GNUTexinfocommandstyletextvar{var in example}
+\\GNUTexinfocommandstyletextcite{cite in example}
 \\end{GNUTexinfopreformatted}
 ';
 
diff --git 
a/tp/t/results/latex_tests/combined_fonts/res_latex/combined_fonts.tex 
b/tp/t/results/latex_tests/combined_fonts/res_latex/combined_fonts.tex
index 102c3542d9..5b23fd1d40 100644
--- a/tp/t/results/latex_tests/combined_fonts/res_latex/combined_fonts.tex
+++ b/tp/t/results/latex_tests/combined_fonts/res_latex/combined_fonts.tex
@@ -15,8 +15,11 @@
 \makeatletter
 \newcommand{\GNUTexinfosettitle}{No Title}%
 
-% style command for cite in codetext
-\newcommand\GNUTexinfocommandstylecodetextcite[1]{{\normalfont{}\textsl{#1}}}%
+% style command for cite in text
+\newcommand\GNUTexinfocommandstyletextcite[1]{{\normalfont{}\textsl{#1}}}%
+
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
 
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
@@ -67,19 +70,19 @@
 \chapter{{chapter}}
 \label{anchor:chapter}%
 
-\texttt{code}, \textsl{dfn}, \textsl{var}, \textbf{strong}, 
{\ttfamily\textsl{kbd}}, `\texttt{samp}'.
+\texttt{code}, \textsl{dfn}, \GNUTexinfocommandstyletextvar{var}, 
\textbf{strong}, {\ttfamily\textsl{kbd}}, `\texttt{samp}'.
 
 \texttt{\textsl{dfn in code}}
-\textsl{\texttt{code in var}}
-\texttt{\textsl{var in code}}
+\GNUTexinfocommandstyletextvar{\texttt{code in var}}
+\texttt{\GNUTexinfocommandstyletextvar{var in code}}
 \textbf{{\ttfamily\textsl{kbd in strong}}}
 `\texttt{\textbf{strong in samp}}'
 \textbf{`\texttt{samp in strong}'}
 
-\textsl{cite}
+\GNUTexinfocommandstyletextcite{cite}
 
-\texttt{\GNUTexinfocommandstylecodetextcite{cite in code}}
-\textsl{\texttt{code in cite}}
+\texttt{\GNUTexinfocommandstyletextcite{cite in code}}
+\GNUTexinfocommandstyletextcite{\texttt{code in cite}}
 
 \texttt{code} \textsl{slanted} \textbf{b}
 \texttt{\textsl{slanted in code}}
@@ -89,7 +92,7 @@
 
 \begin{GNUTexinfopreformatted}
 \leftskip=2em\relax\ttfamily%
-\textsl{var in example}
-\GNUTexinfocommandstylecodetextcite{cite in example}
+\GNUTexinfocommandstyletextvar{var in example}
+\GNUTexinfocommandstyletextcite{cite in example}
 \end{GNUTexinfopreformatted}
 \end{document}
diff --git 
a/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
 
b/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
index 6dcaaeb857..ffe04e05f4 100644
--- 
a/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
+++ 
b/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
@@ -24,6 +24,9 @@
 % command used in \description format for samp
 \newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{{`\texttt{#1}'}}}%
 
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
+
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
 \renewcommand\mainmatter{\clearpage\@mainmattertrue\pagenumbering{arabic}}
@@ -96,19 +99,19 @@ l--ine
 
 \begin{description}
 \item[{\parbox[b]{\linewidth}{%
-\textsl{avar--b}\\
+\GNUTexinfocommandstyletextvar{avar--b}\\
 \index[fn]{avar--b@\texttt{avar{-}{-}b}}%
 \index[cp]{index entry between item and itemx}%
-\textsl{b}
+\GNUTexinfocommandstyletextvar{b}
 \index[fn]{b@\texttt{b}}%
 }}]
 l--ine
 \item[{\parbox[b]{\linewidth}{%
-\textsl{c}\\
+\GNUTexinfocommandstyletextvar{c}\\
 \index[fn]{c@\texttt{c}}%
 
 
-\textsl{d}
+\GNUTexinfocommandstyletextvar{d}
 \index[fn]{d@\texttt{d}}%
 }}]
 
diff --git 
a/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
 
b/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
index be9f597272..c01cf307fc 100644
--- 
a/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
+++ 
b/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
@@ -19,6 +19,9 @@
 
 \makeindex[name=cp]%
 
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
+
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
 \renewcommand\mainmatter{\clearpage\@mainmattertrue\pagenumbering{arabic}}
@@ -69,16 +72,16 @@
 \begin{document}
 \begin{description}
 \item[{\parbox[b]{\linewidth}{%
-\textsl{a--b}\\
+\GNUTexinfocommandstyletextvar{a--b}\\
 \index[cp]{index entry between item and itemx}%
-\textsl{b}\\
+\GNUTexinfocommandstyletextvar{b}\\
 
-\textsl{c}}}]
+\GNUTexinfocommandstyletextvar{c}}}]
 \begin{GNUTexinfopreformatted}
 \leftskip=2em\relax\ttfamily%
 l{-}{-}ine
 \end{GNUTexinfopreformatted}
 \item[{\parbox[b]{\linewidth}{%
-\textsl{d}}}]
+\GNUTexinfocommandstyletextvar{d}}}]
 \end{description}
 \end{document}
diff --git 
a/tp/tests/indices/res_parser/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
 
b/tp/tests/indices/res_parser/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
index 4337c26805..7bb5dffafa 100644
--- 
a/tp/tests/indices/res_parser/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
+++ 
b/tp/tests/indices/res_parser/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
@@ -24,6 +24,9 @@
 % command used in \description format for samp
 \newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{{`\texttt{#1}'}}}%
 
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
+
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
 \renewcommand\mainmatter{\clearpage\@mainmattertrue\pagenumbering{arabic}}
@@ -153,19 +156,19 @@ l--ine
 
 \begin{description}
 \item[{\parbox[b]{\linewidth}{%
-\textsl{avar--b}\\
+\GNUTexinfocommandstyletextvar{avar--b}\\
 \index[fn]{avar--b@\texttt{avar{-}{-}b}}%
 \index[cp]{index entry between item and itemx}%
-\textsl{b}
+\GNUTexinfocommandstyletextvar{b}
 \index[fn]{b@\texttt{b}}%
 }}]
 l--ine
 \item[{\parbox[b]{\linewidth}{%
-\textsl{c}\\
+\GNUTexinfocommandstyletextvar{c}\\
 \index[fn]{c@\texttt{c}}%
 
 
-\textsl{d}
+\GNUTexinfocommandstyletextvar{d}
 \index[fn]{d@\texttt{d}}%
 }}]
 
diff --git 
a/tp/tests/indices/res_parser_info/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
 
b/tp/tests/indices/res_parser_info/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
index 4337c26805..7bb5dffafa 100644
--- 
a/tp/tests/indices/res_parser_info/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
+++ 
b/tp/tests/indices/res_parser_info/indices_in_begin_tables_lists_latex/indices_in_begin_tables_lists.tex
@@ -24,6 +24,9 @@
 % command used in \description format for samp
 \newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{{`\texttt{#1}'}}}%
 
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
+
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
 \renewcommand\mainmatter{\clearpage\@mainmattertrue\pagenumbering{arabic}}
@@ -153,19 +156,19 @@ l--ine
 
 \begin{description}
 \item[{\parbox[b]{\linewidth}{%
-\textsl{avar--b}\\
+\GNUTexinfocommandstyletextvar{avar--b}\\
 \index[fn]{avar--b@\texttt{avar{-}{-}b}}%
 \index[cp]{index entry between item and itemx}%
-\textsl{b}
+\GNUTexinfocommandstyletextvar{b}
 \index[fn]{b@\texttt{b}}%
 }}]
 l--ine
 \item[{\parbox[b]{\linewidth}{%
-\textsl{c}\\
+\GNUTexinfocommandstyletextvar{c}\\
 \index[fn]{c@\texttt{c}}%
 
 
-\textsl{d}
+\GNUTexinfocommandstyletextvar{d}
 \index[fn]{d@\texttt{d}}%
 }}]
 
diff --git a/tp/tests/layout/res_parser/formatting_latex/formatting.tex 
b/tp/tests/layout/res_parser/formatting_latex/formatting.tex
index c28e6a6338..6d24999c69 100644
--- a/tp/tests/layout/res_parser/formatting_latex/formatting.tex
+++ b/tp/tests/layout/res_parser/formatting_latex/formatting.tex
@@ -37,8 +37,11 @@
 % command used in \description format for samp
 \newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{{`\texttt{#1}'}}}%
 
-% style command for cite in codetext
-\newcommand\GNUTexinfocommandstylecodetextcite[1]{{\normalfont{}\textsl{#1}}}%
+% style command for cite in text
+\newcommand\GNUTexinfocommandstyletextcite[1]{{\normalfont{}\textsl{#1}}}%
+
+% style command for var in text
+\newcommand\GNUTexinfocommandstyletextvar[1]{{\normalfont{}\textsl{#1}}}%
 
 % redefine the \mainmatter command such that it does not clear page
 % as if in double page
@@ -246,7 +249,7 @@ but , ,\@
 \texttt{@abbr\{@'E{-}{-}.\ @comma\{\}A.\}} \'{E}--.\@ ,A.\@
 \texttt{@asis\{{-}{-}a\}} --a
 \texttt{@b\{{-}{-}a\}} \textbf{--a}
-\texttt{@cite\{{-}{-}a\}} \textsl{--a}
+\texttt{@cite\{{-}{-}a\}} \GNUTexinfocommandstyletextcite{--a}
 \texttt{@code\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@command\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@dfn\{{-}{-}a\}} \textsl{--a}
@@ -281,7 +284,7 @@ but , ,\@
 \texttt{@url\{{-}{-}a,{-}{-}b\}} \href{--a}{--b (\nolinkurl{--a})}
 \texttt{@url\{{-}{-}a,\}} \url{--a}
 \texttt{@url\{,{-}{-}b\}} --b
-\texttt{@var\{{-}{-}a\}} \textsl{--a}
+\texttt{@var\{{-}{-}a\}} \GNUTexinfocommandstyletextvar{--a}
 \texttt{@verb\{:{-}{-}a:\}} \verb:--a:
 \texttt{@verb\{:a  < \& @ \% " {-}{-}    b:\}} \verb:a  < & @ % " --    b:
 \texttt{@w\{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a\}} \hbox{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a}
@@ -772,11 +775,11 @@ d--effn
 def--fn
 \end{quote}
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \index[cp]{index entry within deffn}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
@@ -871,11 +874,11 @@ def--fn
 
 \index[fn]{deffnx@\texttt{deffnx}}%
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
 
@@ -1538,11 +1541,11 @@ Various deff lines
 
 \index[fn]{after@\texttt{after}}%
 
-\noindent\texttt{\textsl{invalid} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fsetinv]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{invalid} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fsetinv]
 
 
 
-\index[fn]{invalid@\texttt{\textsl{invalid}}}%
+\index[fn]{invalid@\texttt{\GNUTexinfocommandstyletextvar{invalid}}}%
 \noindent\texttt{}\hfill[\textbf{id `\texttt{i}' ule}]
 
 
@@ -1731,7 +1734,7 @@ but , ,\@
 \texttt{@abbr\{@'E{-}{-}.\ @comma\{\}A.\}} \'{E}--.\@ ,A.\@
 \texttt{@asis\{{-}{-}a\}} --a
 \texttt{@b\{{-}{-}a\}} \textbf{--a}
-\texttt{@cite\{{-}{-}a\}} \textsl{--a}
+\texttt{@cite\{{-}{-}a\}} \GNUTexinfocommandstyletextcite{--a}
 \texttt{@code\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@command\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@dfn\{{-}{-}a\}} \textsl{--a}
@@ -1766,7 +1769,7 @@ but , ,\@
 \texttt{@url\{{-}{-}a,{-}{-}b\}} \href{--a}{--b (\nolinkurl{--a})}
 \texttt{@url\{{-}{-}a,\}} \url{--a}
 \texttt{@url\{,{-}{-}b\}} --b
-\texttt{@var\{{-}{-}a\}} \textsl{--a}
+\texttt{@var\{{-}{-}a\}} \GNUTexinfocommandstyletextvar{--a}
 \texttt{@verb\{:{-}{-}a:\}} \verb:--a:
 \texttt{@verb\{:a  < \& @ \% " {-}{-}    b:\}} \verb:a  < & @ % " --    b:
 \texttt{@w\{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a\}} \hbox{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a}
@@ -2254,11 +2257,11 @@ d--effn
 def--fn
 \end{quote}
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \index[cp]{index entry within deffn}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
@@ -2353,11 +2356,11 @@ def--fn
 
 \index[fn]{deffnx@\texttt{deffnx}}%
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
 
@@ -3020,11 +3023,11 @@ Various deff lines
 
 \index[fn]{after@\texttt{after}}%
 
-\noindent\texttt{\textsl{invalid} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fsetinv]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{invalid} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fsetinv]
 
 
 
-\index[fn]{invalid@\texttt{\textsl{invalid}}}%
+\index[fn]{invalid@\texttt{\GNUTexinfocommandstyletextvar{invalid}}}%
 \noindent\texttt{}\hfill[\textbf{id `\texttt{i}' ule}]
 
 
@@ -3234,7 +3237,7 @@ but , ,\@
 \texttt{@abbr\{@'E{-}{-}.\ @comma\{\}A.\}} \'{E}--.\@ ,A.\@
 \texttt{@asis\{{-}{-}a\}} --a
 \texttt{@b\{{-}{-}a\}} \textbf{--a}
-\texttt{@cite\{{-}{-}a\}} \textsl{--a}
+\texttt{@cite\{{-}{-}a\}} \GNUTexinfocommandstyletextcite{--a}
 \texttt{@code\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@command\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@dfn\{{-}{-}a\}} \textsl{--a}
@@ -3269,7 +3272,7 @@ but , ,\@
 \texttt{@url\{{-}{-}a,{-}{-}b\}} \href{--a}{--b (\nolinkurl{--a})}
 \texttt{@url\{{-}{-}a,\}} \url{--a}
 \texttt{@url\{,{-}{-}b\}} --b
-\texttt{@var\{{-}{-}a\}} \textsl{--a}
+\texttt{@var\{{-}{-}a\}} \GNUTexinfocommandstyletextvar{--a}
 \texttt{@verb\{:{-}{-}a:\}} \verb:--a:
 \texttt{@verb\{:a  < \& @ \% " {-}{-}    b:\}} \verb:a  < & @ % " --    b:
 \texttt{@w\{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a\}} \hbox{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a}
@@ -3757,11 +3760,11 @@ d--effn
 def--fn
 \end{quote}
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \index[cp]{index entry within deffn}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
@@ -3856,11 +3859,11 @@ def--fn
 
 \index[fn]{deffnx@\texttt{deffnx}}%
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
 
@@ -4523,11 +4526,11 @@ Various deff lines
 
 \index[fn]{after@\texttt{after}}%
 
-\noindent\texttt{\textsl{invalid} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fsetinv]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{invalid} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fsetinv]
 
 
 
-\index[fn]{invalid@\texttt{\textsl{invalid}}}%
+\index[fn]{invalid@\texttt{\GNUTexinfocommandstyletextvar{invalid}}}%
 \noindent\texttt{}\hfill[\textbf{id `\texttt{i}' ule}]
 
 
@@ -4715,7 +4718,7 @@ but , ,\@
 \texttt{@abbr\{@'E{-}{-}.\ @comma\{\}A.\}} \'{E}--.\@ ,A.\@
 \texttt{@asis\{{-}{-}a\}} --a
 \texttt{@b\{{-}{-}a\}} \textbf{--a}
-\texttt{@cite\{{-}{-}a\}} \textsl{--a}
+\texttt{@cite\{{-}{-}a\}} \GNUTexinfocommandstyletextcite{--a}
 \texttt{@code\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@command\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@dfn\{{-}{-}a\}} \textsl{--a}
@@ -4750,7 +4753,7 @@ but , ,\@
 \texttt{@url\{{-}{-}a,{-}{-}b\}} \href{--a}{--b (\nolinkurl{--a})}
 \texttt{@url\{{-}{-}a,\}} \url{--a}
 \texttt{@url\{,{-}{-}b\}} --b
-\texttt{@var\{{-}{-}a\}} \textsl{--a}
+\texttt{@var\{{-}{-}a\}} \GNUTexinfocommandstyletextvar{--a}
 \texttt{@verb\{:{-}{-}a:\}} \verb:--a:
 \texttt{@verb\{:a  < \& @ \% " {-}{-}    b:\}} \verb:a  < & @ % " --    b:
 \texttt{@w\{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a\}} \hbox{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a}
@@ -5238,11 +5241,11 @@ d--effn
 def--fn
 \end{quote}
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \index[cp]{index entry within deffn}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
@@ -5337,11 +5340,11 @@ def--fn
 
 \index[fn]{deffnx@\texttt{deffnx}}%
 
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
 
@@ -6004,11 +6007,11 @@ Various deff lines
 
 \index[fn]{after@\texttt{after}}%
 
-\noindent\texttt{\textsl{invalid} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fsetinv]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{invalid} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fsetinv]
 
 
 
-\index[fn]{invalid@\texttt{\textsl{invalid}}}%
+\index[fn]{invalid@\texttt{\GNUTexinfocommandstyletextvar{invalid}}}%
 \noindent\texttt{}\hfill[\textbf{id `\texttt{i}' ule}]
 
 
@@ -6198,7 +6201,7 @@ but ,\ ,\@
 \texttt{@abbr\{@'E{-}{-}.\ @comma\{\}A.\}} \'{E}{-}{-}.\@\ ,A.\@
 \texttt{@asis\{{-}{-}a\}} {-}{-}a
 \texttt{@b\{{-}{-}a\}} \textbf{{-}{-}a}
-\texttt{@cite\{{-}{-}a\}} \GNUTexinfocommandstylecodetextcite{{-}{-}a}
+\texttt{@cite\{{-}{-}a\}} \GNUTexinfocommandstyletextcite{{-}{-}a}
 \texttt{@code\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@command\{{-}{-}a\}} \texttt{{-}{-}a}
 \texttt{@dfn\{{-}{-}a\}} \textsl{{-}{-}a}
@@ -6236,7 +6239,7 @@ but ,\ ,\@
 \texttt{@url\{{-}{-}a,{-}{-}b\}} \href{--a}{{-}{-}b (\nolinkurl{--a})}
 \texttt{@url\{{-}{-}a,\}} \url{--a}
 \texttt{@url\{,{-}{-}b\}} {-}{-}b
-\texttt{@var\{{-}{-}a\}} \textsl{{-}{-}a}
+\texttt{@var\{{-}{-}a\}} \GNUTexinfocommandstyletextvar{--a}
 \texttt{@verb\{:{-}{-}a:\}} \verb:--a:
 \texttt{@verb\{:a  < \& @ \% " {-}{-}    b:\}} \verb:a  < & @ % " --    b:
 \texttt{@w\{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a\}} \hbox{a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a}
@@ -7093,11 +7096,11 @@ def{-}{-}fn
 \leftskip=2em\relax\ttfamily%
 
 \end{GNUTexinfopreformatted}
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \begin{GNUTexinfopreformatted}
 \leftskip=2em\relax\ttfamily%
 \index[cp]{index entry within deffn}%
@@ -7210,11 +7213,11 @@ def{-}{-}fn
 \leftskip=2em\relax\ttfamily%
 
 \end{GNUTexinfopreformatted}
-\noindent\texttt{\textsl{i} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fset]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{i} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fset]
 
 
 
-\index[fn]{i@\texttt{\textsl{i}}}%
+\index[fn]{i@\texttt{\GNUTexinfocommandstyletextvar{i}}}%
 \noindent\texttt{truc 
\EmbracOn{}\textnormal{\textsl{}}\EmbracOff{}}\hfill[cmde]
 
 
@@ -8243,11 +8246,11 @@ Various deff lines
 \leftskip=2em\relax\ttfamily%
 
 \end{GNUTexinfopreformatted}
-\noindent\texttt{\textsl{invalid} \EmbracOn{}\textnormal{\textsl{a 
g}}\EmbracOff{}}\hfill[fsetinv]
+\noindent\texttt{\GNUTexinfocommandstyletextvar{invalid} 
\EmbracOn{}\textnormal{\textsl{a g}}\EmbracOff{}}\hfill[fsetinv]
 
 
 
-\index[fn]{invalid@\texttt{\textsl{invalid}}}%
+\index[fn]{invalid@\texttt{\GNUTexinfocommandstyletextvar{invalid}}}%
 \noindent\texttt{}\hfill[\textbf{id `\texttt{i}' ule}]
 
 
@@ -8347,7 +8350,7 @@ g{-}{-}roupe
 
 \index[fn]{@\texttt{\hbox{}}}%
 
-\index[codeidx]{a index---entry te\~{} --- i\^{}@\texttt{a 
\textsl{index{-}{-}{-}entry} t\~{e} {-}{-}{-} \^{\i{}}}}%
+\index[codeidx]{a index---entry te\~{} --- i\^{}@\texttt{a 
\GNUTexinfocommandstyletextvar{index---entry} t\~{e} {-}{-}{-} \^{\i{}}}}%
 
 \index[truc]{truc}%
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/tp/Texinfo/Convert/LaTeX.pm b/tp/Texinfo/Convert/LaTeX.pm
index ca9c528e0d..79d4951be9 100644
--- a/tp/Texinfo/Convert/LaTeX.pm
+++ b/tp/Texinfo/Convert/LaTeX.pm
@@ -74,6 +74,11 @@
 # or two hyphen, no break between __ or hyphen.  See near \global\def\code
 # in texinfo.tex.
 #
+# add a test @frencspacing on in @code (code context) with punctuation.
+#
+# empty line in xtable inter_item_commands_in_table_in_example test leads
+# to ! Paragraph ended before \@item was complete.
+#
 #
 # RELEVANT BUT NOT DECISIVE
 #
@@ -609,8 +614,6 @@ my %LaTeX_style_brace_commands = (
     'r' => '\\textnormal',
     'sc' => '\\textsc',
     'sansserif' => '\\textsf',
-    # slanted in texinfo.tex
-    'cite' => '\\textsl',
   },
   'math' => {
     'hyphenation' => '',
@@ -621,7 +624,6 @@ my %LaTeX_style_brace_commands = (
     'sc' => '', # no obvious way to do it in math mode, not switching to
                 # text mode only for this command
     'sansserif' => '\\mathsf',
-    'cite' => '',
   }
 );
 
@@ -634,14 +636,14 @@ foreach my $LaTeX_style_command_name ('textsc', 'textbf', 
'texttt') {
   $need_known_embrac{'\\'.$LaTeX_style_command_name} = 
$LaTeX_style_command_name;
 }
 
-my $code_text_context = 'codetext';
-
-# in code, we want to keep @cite result in slanted but
-# not in typewriter, so use \normalfont{} to remove other
-# font effects
-register_style_format_command($code_text_context, 'cite',
+# we want to keep those @-commands in roman slanted everywhere in text
+# so use \normalfont{} to remove other font effects
+foreach my $always_slanted_roman_commands ('cite', 'var') {
+  register_style_format_command('text', $always_slanted_roman_commands,
                         '\\normalfont{}\\textsl', \%LaTeX_style_brace_commands,
                         \%style_brace_format_command_new_commands);
+  $LaTeX_style_brace_commands{'math'}->{$always_slanted_roman_commands} = '';
+}
 
 # FIXME headitemfont
 my @asis_commands = ('asis', 'clicksequence', 'headitemfont');
@@ -651,32 +653,23 @@ foreach my $asis_command (@asis_commands) {
   $LaTeX_style_brace_commands{'math'}->{$asis_command} = '';
 }
 
-# in texinfo.tex, @var and @dfn are slanted.
-my @slanted_commands = ('var', 'dfn', 'slanted');
+# in texinfo.tex, @dfn is slanted.
+my @slanted_commands = ('dfn', 'slanted');
 foreach my $slanted_command (@slanted_commands) {
   $LaTeX_style_brace_commands{'text'}->{$slanted_command} = '\\textsl';
   $LaTeX_style_brace_commands{'math'}->{$slanted_command} = '';
-  #register_style_format_command($code_text_context, $slanted_command,
-  #                          '\\ttfamily\\textsl', 
\%LaTeX_style_brace_commands,
-  #                          \%style_brace_format_command_new_commands);
 }
 
 my @emphasized_commands = ('emph');
 foreach my $emphasized_command (@emphasized_commands) {
   $LaTeX_style_brace_commands{'text'}->{$emphasized_command} = '\\emph';
   $LaTeX_style_brace_commands{'math'}->{$emphasized_command} = '';
-  #register_style_format_command($code_text_context, $emphasized_command,
-  #                          '\\ttfamily\\textsl', 
\%LaTeX_style_brace_commands,
-  #                          \%style_brace_format_command_new_commands);
 }
 
 my @bold_commands = ('strong', 'b');
 foreach my $bold_command (@bold_commands) {
   $LaTeX_style_brace_commands{'text'}->{$bold_command} = '\\textbf';
   $LaTeX_style_brace_commands{'math'}->{$bold_command} = '\\mathbf';
-  #register_style_format_command($code_text_context, $bold_command,
-  #                          '\\ttfamily\\textbf', 
\%LaTeX_style_brace_commands,
-  #                          \%style_brace_format_command_new_commands);
 }
 
 my @italics_commands = ('i');
@@ -693,12 +686,6 @@ foreach my $typewriter_command (@typewriter_commands) {
   $LaTeX_style_brace_commands{'math'}->{$typewriter_command} = '\\mathtt';
 }
 
-# Only used in @def* args to avoid accumulating font styles
-my %var_slant_commands = (
-  'var' => '\\rmfamily \\slshape',
-  'code' => '\\upshape \\ttfamily',
-);
-
 my @quoted_commands = ('samp', 'indicateurl');
 
 my %quotes_map;
@@ -734,7 +721,9 @@ foreach my $command 
(keys(%{$LaTeX_style_brace_commands{'text'}}), 'kbd') {
   next if ($unformatted_brace_command{$command});
   my $description_format = $LaTeX_style_brace_commands{'text'}->{$command};
   if ($command eq 'kbd' or
-      ($description_format ne '' and $description_format !~ 
/\\text[a-z]{2}$/)) {
+      ($description_format ne ''
+       and $description_format !~ /\\text[a-z]{2}$/
+       and not $style_brace_format_command_new_commands{'text'}->{$command})) {
     my $specific_format_command
       = "\\${description_command_new_commands_prefix}$command";
     my $command_definition;
@@ -2029,6 +2018,9 @@ sub _xtable_description_command_format($$)
       # only gather if associated to a new command
       if (exists($description_command_new_commands{$command_as_argument})) {
         $self->{'description_format_commands'}->{$command_as_argument} = 1;
+      } elsif 
($style_brace_format_command_new_commands{'text'}->{$command_as_argument}) {
+        $self->{'style_brace_format_commands'}->{'text'}
+                                                     ->{$command_as_argument} 
= 1;
       }
       return $description_command_format{$command_as_argument}
     }
@@ -2456,19 +2448,12 @@ sub _convert($$)
       my $remove_code_context;
       if ($code_style_commands{$cmdname}) {
         $self->{'formatting_context'}->[-1]->{'code'}->[-1] += 1;
-      } elsif ($cmdname eq 'r'
-               or ($cmdname eq 'var'
-                   and $self->{'formatting_context'}->[-1]->{'var_slant'}
-                   and 
$self->{'formatting_context'}->[-1]->{'var_slant'}->[-1])) {
+      } elsif ($cmdname eq 'r' or $cmdname eq 'var') {
         $remove_code_context = 1;
         push @{$self->{'formatting_context'}->[-1]->{'code'}}, 0;
       }
-      # specific macro for typewriter + other style
       my $formatting_context = $command_context;
-      if ($self->{'formatting_context'}->[-1]->{'code'}->[-1]
-          and $command_context eq 'text'
-          and $LaTeX_style_brace_commands{$code_text_context}->{$cmdname}) {
-        $formatting_context = $code_text_context;
+      if 
($style_brace_format_command_new_commands{$formatting_context}->{$cmdname}) {
         $self->{'style_brace_format_commands'}->{$formatting_context}
                                                      ->{$cmdname} = 1;
       }
@@ -2488,14 +2473,7 @@ sub _convert($$)
                        ->{'made_known'}->{$defined_style_embrac} = 1;
           }
         }
-        if ($var_slant_commands{$cmdname}
-            and $self->{'formatting_context'}->[-1]->{'var_slant'}
-            and $self->{'formatting_context'}->[-1]->{'var_slant'}->[-1]) {
-          $result .= '{' . $var_slant_commands{$cmdname} . ' ';
-          # FIXME \EmbracMakeKnown for these commands too?
-        } else {
-          $result .= "$LaTeX_style_command\{";
-        }
+        $result .= "$LaTeX_style_command\{";
       }
       if ($element->{'args'}) {
         $result .= _convert($self, $element->{'args'}->[0]);
@@ -3628,7 +3606,6 @@ sub _convert($$)
         my $known_embrac_commands;
         if ($arguments) {
           $result .= $def_space;
-          push @{$self->{'formatting_context'}->[-1]->{'var_slant'}}, 1;
           if ($Texinfo::Common::def_no_var_arg_commands{$command}) {
             $result .= _convert($self, {'contents' => $arguments});
           } else {
@@ -3654,7 +3631,6 @@ sub _convert($$)
                 = [sort(keys(%{$closed_embrac->{'made_known'}}))]
             }
           }
-          pop @{$self->{'formatting_context'}->[-1]->{'var_slant'}};
         }
 
         $self->{'formatting_context'}->[-1]->{'code'}->[-1] -= 1;